@@ -18,7 +18,7 @@
 
 from __future__ import annotations
 
-from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import AirflowException
 
 
 class AirflowExternalTaskSensorException(AirflowException):
