@@ -24,13 +24,13 @@ from typing import TYPE_CHECKING, Any
 
 from airflow.configuration import conf
 from airflow.exceptions import AirflowProviderDeprecationWarning
+from airflow.providers.common.compat.sdk import BaseSensorOperator, timezone
 from airflow.providers.standard.triggers.temporal import DateTimeTrigger
-from airflow.providers.standard.version_compat import BaseSensorOperator
 
 try:
-    from airflow.triggers.base import StartTriggerArgs
-except ImportError:
-    # TODO: Remove this when min airflow version is 2.10.0 for standard provider
+    from airflow.triggers.base import StartTriggerArgs  # type: ignore[no-redef]
+except ImportError:  # TODO: Remove this when min airflow version is 2.10.0 for standard provider
+
     @dataclass
     class StartTriggerArgs:  # type: ignore[no-redef]
         """Arguments required for start task execution from triggerer."""
@@ -42,17 +42,8 @@ except ImportError:
         timeout: datetime.timedelta | None = None
 
 
-try:
-    from airflow.sdk import timezone
-except ImportError:
-    from airflow.utils import timezone  # type: ignore[attr-defined,no-redef]
-
 if TYPE_CHECKING:
-    try:
-        from airflow.sdk.definitions.context import Context
-    except ImportError:
-        # TODO: Remove once provider drops support for Airflow 2
-        from airflow.utils.context import Context
+    from airflow.sdk import Context
 
 
 class TimeSensor(BaseSensorOperator):
